from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class StripeSetupIntentModelDefinition(BaseModel):
    setup_intent_client_secret: Optional[str] = None
    tracking_id: Optional[str] = None


StripeSetupIntentModelDefinition.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.country import Country
from pianosdk.publisher.models.term_brief import TermBrief
from typing import List


class DeliveryZone(BaseModel):
    delivery_zone_id: Optional[str] = None
    delivery_zone_name: Optional[str] = None
    countries: Optional['List[Country]'] = None
    terms: Optional['List[TermBrief]'] = None


DeliveryZone.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class PublisherPasswordRequest(BaseModel):
    aid: Optional[str] = None
    uid: Optional[str] = None
    password: Optional[str] = None
    current_password: Optional[str] = None
    force_update: Optional[bool] = None


PublisherPasswordRequest.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.variant_item import VariantItem
from pianosdk.publisher.models.version_item import VersionItem
from typing import List


class ImportItem(BaseModel):
    item_id: Optional[str] = None
    name: Optional[str] = None
    action: Optional[str] = None
    import_result: Optional[str] = None
    update_date: Optional[int] = None
    count_variants: Optional[int] = None
    variant_list: Optional['List[VariantItem]'] = None
    version: Optional[int] = None
    version_list: Optional['List[VersionItem]'] = None


ImportItem.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class ZuoraConfiguration(BaseModel):
    api_key: Optional[str] = None
    api_secret: Optional[str] = None
    entity_name: Optional[str] = None
    entity_id: Optional[str] = None


ZuoraConfiguration.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class EraseUserAddress(BaseModel):
    user_address_id: Optional[str] = None
    region_id: Optional[str] = None
    region_name: Optional[str] = None
    region_code: Optional[str] = None
    country_name: Optional[str] = None
    city: Optional[str] = None
    postal_code: Optional[str] = None
    company_name: Optional[str] = None
    first_name: Optional[str] = None
    last_name: Optional[str] = None
    address1: Optional[str] = None
    address2: Optional[str] = None
    phone: Optional[str] = None
    additional_fields: Optional[str] = None


EraseUserAddress.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class LanguageStats(BaseModel):
    template_keys_count: Optional[int] = None
    template_keys_abandoned: Optional[int] = None
    unit_keys_count: Optional[int] = None
    unit_keys_abandoned: Optional[int] = None
    locale: Optional[str] = None


LanguageStats.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.linked_term_conversion_params import LinkedTermConversionParams
from pianosdk.publisher.models.linked_term_shared_access_params import LinkedTermSharedAccessParams
from pianosdk.publisher.models.linked_term_subscription_params import LinkedTermSubscriptionParams


class LinkedTermEventRequest(BaseModel):
    action: Optional[str] = None
    session_id: Optional[str] = None
    subscription: Optional['LinkedTermSubscriptionParams'] = None
    conversion: Optional['LinkedTermConversionParams'] = None
    shared_access: Optional['LinkedTermSharedAccessParams'] = None


LinkedTermEventRequest.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class TargetIneligibleTerm(BaseModel):
    term_id: Optional[str] = None
    name: Optional[str] = None
    tooltip: Optional[str] = None
    enabled: Optional[bool] = None


TargetIneligibleTerm.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class TemplateVersion(BaseModel):
    template_version_id: Optional[str] = None
    template_id: Optional[str] = None
    name: Optional[str] = None
    comment: Optional[str] = None
    subject: Optional[str] = None
    body: Optional[str] = None
    html: Optional[str] = None
    css: Optional[str] = None
    version: Optional[int] = None
    lang: Optional[str] = None
    published: Optional[bool] = None
    create_date: Optional[datetime] = None
    update_date: Optional[datetime] = None
    xdays: Optional[int] = None


TemplateVersion.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.audit_changed_field_dto import AuditChangedFieldDto
from typing import List


class UserAudit(BaseModel):
    user_audit_id: Optional[str] = None
    uid: Optional[str] = None
    session_id: Optional[str] = None
    country_name: Optional[str] = None
    city: Optional[str] = None
    user_agent: Optional[str] = None
    visited: Optional[datetime] = None
    action_type: Optional[str] = None
    aid: Optional[str] = None
    changed_fields: Optional['List[AuditChangedFieldDto]'] = None


UserAudit.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class SubscriptionReallocationError(BaseModel):
    error_message: Optional[str] = None
    error_element_index: Optional[int] = None
    field_name: Optional[str] = None


SubscriptionReallocationError.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.pay_source_dto import PaySourceDTO
from pianosdk.publisher.models.user import User
from typing import List


class CheckoutFlow(BaseModel):
    checkout_flow_id: Optional[str] = None
    name: Optional[str] = None
    checkout_flow_type: Optional[str] = None
    description: Optional[str] = None
    create_date: Optional[datetime] = None
    create_by: Optional['User'] = None
    update_date: Optional[datetime] = None
    update_by: Optional['User'] = None
    is_passwordless: Optional[bool] = None
    is_single_step_enabled: Optional[bool] = None
    is_auto_detect_email: Optional[bool] = None
    is_custom_checkout_modules_enabled: Optional[bool] = None
    deleted: Optional[bool] = None
    pay_sources: Optional['List[PaySourceDTO]'] = None
    inline_checkout_modules: Optional[List[str]] = None
    modal_checkout_modules: Optional[List[str]] = None


CheckoutFlow.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class TaxCountry(BaseModel):
    country_name: Optional[str] = None
    country_code: Optional[str] = None
    requires_zip_code: Optional[bool] = None
    need_residence: Optional[bool] = None
    include_billing: Optional[bool] = None
    tax_support: Optional[str] = None


TaxCountry.model_rebuild()



from pianosdk.id.api.identity_api import IdentityApi
from pianosdk.id.api.identity_oauth_api import IdentityOauthApi
from pianosdk.id.api.identity_token_api import IdentityTokenApi
from pianosdk.id.api.publisher_api import PublisherApi
from pianosdk.id.api.publisher_audit_api import PublisherAuditApi
from pianosdk.id.api.publisher_form_api import PublisherFormApi
from pianosdk.id.api.publisher_identity_api import PublisherIdentityApi
from pianosdk.id.api.publisher_identity_doi_api import PublisherIdentityDoiApi
from pianosdk.id.api.publisher_identity_session_api import PublisherIdentitySessionApi
from pianosdk.id.api.publisher_identity_set_api import PublisherIdentitySetApi
from pianosdk.id.api.publisher_import_custom_fields_api import PublisherImportCustomFieldsApi
from pianosdk.id.api.publisher_link_api import PublisherLinkApi
from pianosdk.id.api.publisher_login_api import PublisherLoginApi
from pianosdk.id.api.publisher_login_social_api import PublisherLoginSocialApi
from pianosdk.id.api.publisher_reset_api import PublisherResetApi
from pianosdk.id.api.publisher_social_api import PublisherSocialApi
from pianosdk.id.api.publisher_token_api import PublisherTokenApi
from pianosdk.id.api.publisher_userinfo_api import PublisherUserinfoApi
from pianosdk.id.api.publisher_users_api import PublisherUsersApi



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.billing_timing_option import BillingTimingOption
from pianosdk.publisher.models.term_short import TermShort


class UpgradeSubscriptionStep(BaseModel):
    from_term: Optional['TermShort'] = None
    to_term: Optional['TermShort'] = None
    billing_timing: Optional['BillingTimingOption'] = None
    immediate_access: Optional[bool] = None
    include_auto_renew_off: Optional[bool] = None
    do_not_send_emails: Optional[bool] = None
    do_not_send_cancellation_emails: Optional[bool] = None


UpgradeSubscriptionStep.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class OAuthRequest(BaseModel):
    client_id: Optional[str] = None
    refresh_token: Optional[str] = None
    grant_type: Optional[str] = None
    code: Optional[str] = None
    client_secret: Optional[str] = None
    redirect_uri: Optional[str] = None
    code_verifier: Optional[str] = None


OAuthRequest.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class AfcConfiguration(BaseModel):
    afc_client_id: Optional[str] = None
    afc_username: Optional[str] = None
    afc_password: Optional[str] = None
    afc_client_profile_id: Optional[str] = None


AfcConfiguration.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.price_dto import PriceDTO
from typing import List


class PromotionTermStats(BaseModel):
    pub_id: Optional[str] = None
    term_pub_id: Optional[str] = None
    total_sales: Optional['List[PriceDTO]'] = None
    conversion: Optional[int] = None


PromotionTermStats.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class EraseSubscription(BaseModel):
    subscription_id: Optional[str] = None


EraseSubscription.model_rebuild()



from datetime import datetime
from io import StringIO
from typing import TextIO, Dict, List, Union

from pianosdk.api_response import ApiResponse
from pianosdk.base_api import BaseApi
from pianosdk.configuration import Configuration
from pianosdk.httpwrap import HttpCallBack
from pianosdk.utils import _json_deserialize, _encode_parameter
from pianosdk.publisher.models.contract_user import ContractUser


class PublisherLicensingContractUserApi(BaseApi):
    def __init__(self, config: Configuration, http_callback: HttpCallBack = None) -> None:
        super().__init__(config, http_callback)

    def create_contract_user(self, aid: str, contract_id: str, email: str, first_name: str = None, last_name: str = None, contract_user_session_id: str = None) -> ApiResponse[ContractUser]:
        _url_path = '/api/v3/publisher/licensing/contractUser/create'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'contract_id': _encode_parameter(contract_id),
            'email': _encode_parameter(email),
            'first_name': _encode_parameter(first_name),
            'last_name': _encode_parameter(last_name),
            'contract_user_session_id': _encode_parameter(contract_user_session_id)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, ContractUser)
        return _result

    def get_contract_user_list(self, aid: str, contract_id: str, offset: int = 0, limit: int = 100, order_by: str = 'email', order_direction: str = None, status_list: List[str] = None, q: str = None) -> ApiResponse[List[ContractUser]]:
        _url_path = '/api/v3/publisher/licensing/contractUser/list'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {
            'aid': _encode_parameter(aid),
            'contract_id': _encode_parameter(contract_id),
            'order_by': _encode_parameter(order_by),
            'order_direction': _encode_parameter(order_direction),
            'status_list': _encode_parameter(status_list),
            'q': _encode_parameter(q),
            'offset': _encode_parameter(offset),
            'limit': _encode_parameter(limit)
        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {

        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('GET',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, ContractUser)
        return _result

    def invite_contract_users(self, aid: str, contract_id: str, contract_user_session_id: str = None) -> ApiResponse[Dict]:
        _url_path = '/api/v3/publisher/licensing/contractUser/invite'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'contract_id': _encode_parameter(contract_id),
            'contract_user_session_id': _encode_parameter(contract_user_session_id)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response)
        return _result

    def remove_and_revoke_contract_user(self, aid: str, contract_id: str, contract_user_id: str, contract_user_session_id: str = None) -> ApiResponse[Dict]:
        _url_path = '/api/v3/publisher/licensing/contractUser/removeAndRevoke'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'contract_id': _encode_parameter(contract_id),
            'contract_user_id': _encode_parameter(contract_user_id),
            'contract_user_session_id': _encode_parameter(contract_user_session_id)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response)
        return _result

    def remove_contract_user(self, aid: str, contract_id: str, contract_user_id: str) -> ApiResponse[Dict]:
        _url_path = '/api/v3/publisher/licensing/contractUser/remove'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'contract_id': _encode_parameter(contract_id),
            'contract_user_id': _encode_parameter(contract_user_id)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response)
        return _result

    def restore_contract_user(self, aid: str, contract_id: str, contract_user_id: str) -> ApiResponse[Dict]:
        _url_path = '/api/v3/publisher/licensing/contractUser/restore'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'contract_id': _encode_parameter(contract_id),
            'contract_user_id': _encode_parameter(contract_user_id)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response)
        return _result

    def revoke_contract_user(self, aid: str, contract_id: str, contract_user_id: str) -> ApiResponse[Dict]:
        _url_path = '/api/v3/publisher/licensing/contractUser/revoke'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'contract_id': _encode_parameter(contract_id),
            'contract_user_id': _encode_parameter(contract_user_id)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response)
        return _result

    def update_contract_user(self, aid: str, contract_id: str, contract_user_id: str, email: str, first_name: str = None, last_name: str = None, contract_user_session_id: str = None) -> ApiResponse[ContractUser]:
        _url_path = '/api/v3/publisher/licensing/contractUser/update'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'contract_id': _encode_parameter(contract_id),
            'contract_user_id': _encode_parameter(contract_user_id),
            'email': _encode_parameter(email),
            'first_name': _encode_parameter(first_name),
            'last_name': _encode_parameter(last_name),
            'contract_user_session_id': _encode_parameter(contract_user_session_id)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, ContractUser)
        return _result




from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.access_period import AccessPeriod
from typing import List


class DynamicSubscriptionDetails(BaseModel):
    renewal_type: Optional[str] = None
    term_periods: Optional['List[AccessPeriod]'] = None
    scheduled_period_id: Optional[str] = None
    has_ongoing_periods: Optional[bool] = None
    can_renew_now: Optional[bool] = None
    can_be_resumed: Optional[bool] = None
    deferred_cancelable: Optional[bool] = None


DynamicSubscriptionDetails.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class Resource(BaseModel):
    rid: Optional[str] = None
    aid: Optional[str] = None
    publish_date: Optional[datetime] = None
    name: Optional[str] = None
    description: Optional[str] = None
    image_url: Optional[str] = None
    purchase_url: Optional[str] = None


Resource.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.import_user import ImportUser
from typing import List


class UsersImportResult(BaseModel):
    failed_to_process_emails: Optional['List[ImportUser]'] = None


UsersImportResult.model_rebuild()



from datetime import datetime
from io import StringIO
from typing import TextIO, Dict, List, Union

from pianosdk.api_response import ApiResponse
from pianosdk.base_api import BaseApi
from pianosdk.configuration import Configuration
from pianosdk.httpwrap import HttpCallBack
from pianosdk.utils import _json_deserialize, _encode_parameter


class PublisherLinkApi(BaseApi):
    def __init__(self, config: Configuration, http_callback: HttpCallBack = None) -> None:
        super().__init__(config, http_callback)

    def link_social(self, aid: str, uid: str, social_type: str, redirect_uri: str, ab_test_ids: List[str] = None, affiliate: bool = None, response_type: str = None, authorization: str = None, form_id: str = None) -> ApiResponse[Dict]:
        _url_path = '/id/api/v1/publisher/link/social'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {
            'aid': _encode_parameter(aid),
            'uid': _encode_parameter(uid),
            'social_type': _encode_parameter(social_type),
            'redirect_uri': _encode_parameter(redirect_uri),
            'ab_test_ids': _encode_parameter(ab_test_ids),
            'affiliate': _encode_parameter(affiliate),
            'response_type': _encode_parameter(response_type),
            'form_id': _encode_parameter(form_id)
        }

        _headers = {
            'Authorization': authorization,
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {

        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response)
        return _result




from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.credit_guard_stored_fields import CreditGuardStoredFields
from pianosdk.publisher.models.term import Term
from pianosdk.publisher.models.user import User
from pianosdk.publisher.models.user_subscription import UserSubscription
from typing import Any


class UserPaymentDetailsDTO(BaseModel):
    user_payment_id: Optional[str] = None
    create_date: Optional[str] = None
    renewal: Optional[bool] = None
    refund_amount: Optional[float] = None
    remaining_amount: Optional[float] = None
    amount: Optional[float] = None
    price: Optional[str] = None
    refund_currency: Optional[str] = None
    currency: Optional[str] = None
    refundable: Optional[bool] = None
    subscription: Optional['UserSubscription'] = None
    term: Optional['Term'] = None
    user: Optional['User'] = None
    tax: Optional[float] = None
    hst_amount: Optional[float] = None
    qst_amount: Optional[float] = None
    pst_amount: Optional[float] = None
    gst_amount: Optional[float] = None
    tax_rate: Optional[float] = None
    hst_rate: Optional[float] = None
    qst_rate: Optional[float] = None
    pst_rate: Optional[float] = None
    gst_rate: Optional[float] = None
    tax_billing_country_code: Optional[str] = None
    tax_residence_country_code: Optional[str] = None
    zip_code: Optional[str] = None
    tax_billing_zip_code: Optional[str] = None
    geo_location_country: Optional[str] = None
    tax_billing_plan: Optional[str] = None
    billing_plan: Optional[str] = None
    user_payment_info_id: Optional[str] = None
    payment_method: Optional[str] = None
    transaction_details: Optional['Any'] = None
    source_id: Optional[int] = None
    source_name: Optional[str] = None
    upi_ext_customer_id: Optional[str] = None
    upi_ext_customer_id_label: Optional[str] = None
    external_transaction_id: Optional[str] = None
    tracking_id: Optional[str] = None
    original_price: Optional[str] = None
    status: Optional[str] = None
    status_value: Optional[int] = None
    refunded_amount: Optional[float] = None
    refund_amount_recalculated: Optional[bool] = None
    invoice_number: Optional[str] = None
    stored_fields: Optional['CreditGuardStoredFields'] = None
    link_to_external_payment: Optional[str] = None
    link_to_external_customer: Optional[str] = None


UserPaymentDetailsDTO.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.schedule_period import SchedulePeriod
from typing import List


class Contract(BaseModel):
    contract_id: Optional[str] = None
    aid: Optional[str] = None
    name: Optional[str] = None
    description: Optional[str] = None
    create_date: Optional[datetime] = None
    landing_page_url: Optional[str] = None
    licensee_id: Optional[str] = None
    seats_number: Optional[int] = None
    is_hard_seats_limit_type: Optional[bool] = None
    rid: Optional[str] = None
    schedule_id: Optional[str] = None
    contract_is_active: Optional[bool] = None
    contract_type: Optional[str] = None
    contract_conversions_count: Optional[int] = None
    contract_periods: Optional['List[SchedulePeriod]'] = None


Contract.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class TermBrief(BaseModel):
    term_id: Optional[str] = None
    name: Optional[str] = None
    disabled: Optional[bool] = None


TermBrief.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class TermFrom(BaseModel):
    name: Optional[str] = None
    type: Optional[str] = None
    from_term_id: Optional[str] = None
    from_term_name: Optional[str] = None
    from_period_id: Optional[str] = None
    from_period_name: Optional[str] = None


TermFrom.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.source import Source
from typing import List


class KeySource(BaseModel):
    key: Optional[str] = None
    key_sources: Optional['List[Source]'] = None


KeySource.model_rebuild()



from pianosdk.publisher.api.publisher_adblocker_api import PublisherAdblockerApi
from pianosdk.publisher.api.publisher_afc_configuration_api import PublisherAfcConfigurationApi
from pianosdk.publisher.api.publisher_app_api import PublisherAppApi
from pianosdk.publisher.api.publisher_app_api_token_api import PublisherAppApiTokenApi
from pianosdk.publisher.api.publisher_app_features_api import PublisherAppFeaturesApi
from pianosdk.publisher.api.publisher_consent_api import PublisherConsentApi
from pianosdk.publisher.api.publisher_consent_entry_api import PublisherConsentEntryApi
from pianosdk.publisher.api.publisher_conversion_api import PublisherConversionApi
from pianosdk.publisher.api.publisher_conversion_custom_api import PublisherConversionCustomApi
from pianosdk.publisher.api.publisher_conversion_data_api import PublisherConversionDataApi
from pianosdk.publisher.api.publisher_conversion_external_api import PublisherConversionExternalApi
from pianosdk.publisher.api.publisher_conversion_registration_api import PublisherConversionRegistrationApi
from pianosdk.publisher.api.publisher_email_confirmation_api import PublisherEmailConfirmationApi
from pianosdk.publisher.api.publisher_experience_metadata_api import PublisherExperienceMetadataApi
from pianosdk.publisher.api.publisher_export_api import PublisherExportApi
from pianosdk.publisher.api.publisher_export_create_api import PublisherExportCreateApi
from pianosdk.publisher.api.publisher_export_create_aam_api import PublisherExportCreateAamApi
from pianosdk.publisher.api.publisher_export_create_aam_monthly_api import PublisherExportCreateAamMonthlyApi
from pianosdk.publisher.api.publisher_export_create_access_report_export_api import PublisherExportCreateAccessReportExportApi
from pianosdk.publisher.api.publisher_export_create_subscription_details_report_api import PublisherExportCreateSubscriptionDetailsReportApi
from pianosdk.publisher.api.publisher_export_create_transactions_report_api import PublisherExportCreateTransactionsReportApi
from pianosdk.publisher.api.publisher_external_provider_payment_api import PublisherExternalProviderPaymentApi
from pianosdk.publisher.api.publisher_gdpr_api import PublisherGdprApi
from pianosdk.publisher.api.publisher_inquiry_api import PublisherInquiryApi
from pianosdk.publisher.api.publisher_licensing_contract_api import PublisherLicensingContractApi
from pianosdk.publisher.api.publisher_licensing_contract_domain_api import PublisherLicensingContractDomainApi
from pianosdk.publisher.api.publisher_licensing_contract_domain_contract_user_api import PublisherLicensingContractDomainContractUserApi
from pianosdk.publisher.api.publisher_licensing_contract_ip_range_api import PublisherLicensingContractIpRangeApi
from pianosdk.publisher.api.publisher_licensing_contract_periods_api import PublisherLicensingContractPeriodsApi
from pianosdk.publisher.api.publisher_licensing_contract_user_api import PublisherLicensingContractUserApi
from pianosdk.publisher.api.publisher_licensing_licensee_api import PublisherLicensingLicenseeApi
from pianosdk.publisher.api.publisher_licensing_notification_api import PublisherLicensingNotificationApi
from pianosdk.publisher.api.publisher_licensing_notification_rule_api import PublisherLicensingNotificationRuleApi
from pianosdk.publisher.api.publisher_licensing_schedule_api import PublisherLicensingScheduleApi
from pianosdk.publisher.api.publisher_licensing_schedule_contract_periods_api import PublisherLicensingScheduleContractPeriodsApi
from pianosdk.publisher.api.publisher_linked_term_api import PublisherLinkedTermApi
from pianosdk.publisher.api.publisher_linked_term_custom_field_api import PublisherLinkedTermCustomFieldApi
from pianosdk.publisher.api.publisher_offer_api import PublisherOfferApi
from pianosdk.publisher.api.publisher_offer_template_api import PublisherOfferTemplateApi
from pianosdk.publisher.api.publisher_offer_template_create_api import PublisherOfferTemplateCreateApi
from pianosdk.publisher.api.publisher_offer_template_inherited_api import PublisherOfferTemplateInheritedApi
from pianosdk.publisher.api.publisher_offer_template_update_api import PublisherOfferTemplateUpdateApi
from pianosdk.publisher.api.publisher_offer_template_variant_api import PublisherOfferTemplateVariantApi
from pianosdk.publisher.api.publisher_offer_term_api import PublisherOfferTermApi
from pianosdk.publisher.api.publisher_offer_term_offer_api import PublisherOfferTermOfferApi
from pianosdk.publisher.api.publisher_payment_api import PublisherPaymentApi
from pianosdk.publisher.api.publisher_payment_method_api import PublisherPaymentMethodApi
from pianosdk.publisher.api.publisher_payment_method_billing_address_api import PublisherPaymentMethodBillingAddressApi
from pianosdk.publisher.api.publisher_payment_method_gmo_api import PublisherPaymentMethodGmoApi
from pianosdk.publisher.api.publisher_payment_provider_configuration_api import PublisherPaymentProviderConfigurationApi
from pianosdk.publisher.api.publisher_platform_billing_configuration_api import PublisherPlatformBillingConfigurationApi
from pianosdk.publisher.api.publisher_platform_billing_configuration_account_api import PublisherPlatformBillingConfigurationAccountApi
from pianosdk.publisher.api.publisher_promotion_api import PublisherPromotionApi
from pianosdk.publisher.api.publisher_promotion_code_api import PublisherPromotionCodeApi
from pianosdk.publisher.api.publisher_promotion_fixed_discount_api import PublisherPromotionFixedDiscountApi
from pianosdk.publisher.api.publisher_promotion_term_api import PublisherPromotionTermApi
from pianosdk.publisher.api.publisher_resource_api import PublisherResourceApi
from pianosdk.publisher.api.publisher_resource_bundle_api import PublisherResourceBundleApi
from pianosdk.publisher.api.publisher_resource_cross_app_api import PublisherResourceCrossAppApi
from pianosdk.publisher.api.publisher_resource_stats_api import PublisherResourceStatsApi
from pianosdk.publisher.api.publisher_resource_tag_api import PublisherResourceTagApi
from pianosdk.publisher.api.publisher_resource_user_api import PublisherResourceUserApi
from pianosdk.publisher.api.publisher_schedule_api import PublisherScheduleApi
from pianosdk.publisher.api.publisher_schedule_period_api import PublisherSchedulePeriodApi
from pianosdk.publisher.api.publisher_subscription_api import PublisherSubscriptionApi
from pianosdk.publisher.api.publisher_subscription_address_api import PublisherSubscriptionAddressApi
from pianosdk.publisher.api.publisher_subscription_cancel_api import PublisherSubscriptionCancelApi
from pianosdk.publisher.api.publisher_subscription_share_api import PublisherSubscriptionShareApi
from pianosdk.publisher.api.publisher_subscription_share_user_api import PublisherSubscriptionShareUserApi
from pianosdk.publisher.api.publisher_team_api import PublisherTeamApi
from pianosdk.publisher.api.publisher_term_api import PublisherTermApi
from pianosdk.publisher.api.publisher_term_change_api import PublisherTermChangeApi
from pianosdk.publisher.api.publisher_term_change_option_api import PublisherTermChangeOptionApi
from pianosdk.publisher.api.publisher_term_custom_api import PublisherTermCustomApi
from pianosdk.publisher.api.publisher_term_dynamic_api import PublisherTermDynamicApi
from pianosdk.publisher.api.publisher_term_external_api import PublisherTermExternalApi
from pianosdk.publisher.api.publisher_term_gift_api import PublisherTermGiftApi
from pianosdk.publisher.api.publisher_term_payment_api import PublisherTermPaymentApi
from pianosdk.publisher.api.publisher_term_registration_api import PublisherTermRegistrationApi
from pianosdk.publisher.api.publisher_term_stats_api import PublisherTermStatsApi
from pianosdk.publisher.api.publisher_test_api import PublisherTestApi
from pianosdk.publisher.api.publisher_user_api import PublisherUserApi
from pianosdk.publisher.api.publisher_user_access_api import PublisherUserAccessApi
from pianosdk.publisher.api.publisher_user_access_active_api import PublisherUserAccessActiveApi
from pianosdk.publisher.api.publisher_user_address_api import PublisherUserAddressApi
from pianosdk.publisher.api.publisher_user_app_api import PublisherUserAppApi
from pianosdk.publisher.api.publisher_user_billing_address_api import PublisherUserBillingAddressApi
from pianosdk.publisher.api.publisher_user_bulk_import_api import PublisherUserBulkImportApi
from pianosdk.publisher.api.publisher_user_email_api import PublisherUserEmailApi
from pianosdk.publisher.api.publisher_user_list_api import PublisherUserListApi
from pianosdk.publisher.api.publisher_user_note_api import PublisherUserNoteApi
from pianosdk.publisher.api.publisher_voucher_api import PublisherVoucherApi
from pianosdk.publisher.api.publisher_webhook_api import PublisherWebhookApi
from pianosdk.publisher.api.publisher_webhook_response_api import PublisherWebhookResponseApi
from pianosdk.publisher.api.publisher_webhook_settings_api import PublisherWebhookSettingsApi

from pianosdk.publisher.models.access import Access
from pianosdk.publisher.models.access_dto import AccessDTO
from pianosdk.publisher.models.access_period import AccessPeriod
from pianosdk.publisher.models.access_period_stats import AccessPeriodStats
from pianosdk.publisher.models.action import Action
from pianosdk.publisher.models.action_dto import ActionDTO
from pianosdk.publisher.models.action_step_dto import ActionStepDTO
from pianosdk.publisher.models.address_config import AddressConfig
from pianosdk.publisher.models.address_usage_info import AddressUsageInfo
from pianosdk.publisher.models.advanced_email_model import AdvancedEmailModel
from pianosdk.publisher.models.advanced_options import AdvancedOptions
from pianosdk.publisher.models.afc_configuration import AfcConfiguration
from pianosdk.publisher.models.app import App
from pianosdk.publisher.models.app_features import AppFeatures
from pianosdk.publisher.models.app_resource_count import AppResourceCount
from pianosdk.publisher.models.apply_payment_method_dto import ApplyPaymentMethodDTO
from pianosdk.publisher.models.audit_changed_field_dto import AuditChangedFieldDto
from pianosdk.publisher.models.avalara_configuration import AvalaraConfiguration
from pianosdk.publisher.models.avalara_origin_address import AvalaraOriginAddress
from pianosdk.publisher.models.bill import Bill
from pianosdk.publisher.models.billing_plan_table import BillingPlanTable
from pianosdk.publisher.models.billing_timing_option import BillingTimingOption
from pianosdk.publisher.models.brain_tree_create_credit_card_info_dto import BrainTreeCreateCreditCardInfoDto
from pianosdk.publisher.models.braintree_configuration import BraintreeConfiguration
from pianosdk.publisher.models.braintree_merchant_account_id_entry import BraintreeMerchantAccountIdEntry
from pianosdk.publisher.models.browser_segment import BrowserSegment
from pianosdk.publisher.models.bulk_user_import import BulkUserImport
from pianosdk.publisher.models.bulk_user_import_processing_request_dto import BulkUserImportProcessingRequestDto
from pianosdk.publisher.models.c2_experience_config import C2ExperienceConfig
from pianosdk.publisher.models.categories_counter_model import CategoriesCounterModel
from pianosdk.publisher.models.change_subscription_term_step import ChangeSubscriptionTermStep
from pianosdk.publisher.models.check_can_upgrade_result import CheckCanUpgradeResult
from pianosdk.publisher.models.check_users_email_result import CheckUsersEmailResult
from pianosdk.publisher.models.checkout_flow import CheckoutFlow
from pianosdk.publisher.models.checkout_flow_light_model import CheckoutFlowLightModel
from pianosdk.publisher.models.churn_prevention_email import ChurnPreventionEmail
from pianosdk.publisher.models.churn_prevention_logic import ChurnPreventionLogic
from pianosdk.publisher.models.churn_prevention_template_version import ChurnPreventionTemplateVersion
from pianosdk.publisher.models.comment_action import CommentAction
from pianosdk.publisher.models.composer import Composer
from pianosdk.publisher.models.configuration_property_metadata import ConfigurationPropertyMetadata
from pianosdk.publisher.models.consent import Consent
from pianosdk.publisher.models.consent_box_entry import ConsentBoxEntry
from pianosdk.publisher.models.continuous_renewal_details import ContinuousRenewalDetails
from pianosdk.publisher.models.contract import Contract
from pianosdk.publisher.models.contract_details import ContractDetails
from pianosdk.publisher.models.contract_domain import ContractDomain
from pianosdk.publisher.models.contract_ip_range import ContractIpRange
from pianosdk.publisher.models.contract_user import ContractUser
from pianosdk.publisher.models.conversion_value_dto import ConversionValueDTO
from pianosdk.publisher.models.country import Country
from pianosdk.publisher.models.country_model import CountryModel
from pianosdk.publisher.models.country_simple_model import CountrySimpleModel
from pianosdk.publisher.models.create_access_period_params import CreateAccessPeriodParams
from pianosdk.publisher.models.create_billing_configuration_request import CreateBillingConfigurationRequest
from pianosdk.publisher.models.create_linked_term_request import CreateLinkedTermRequest
from pianosdk.publisher.models.credit_guard_stored_fields import CreditGuardStoredFields
from pianosdk.publisher.models.currency import Currency
from pianosdk.publisher.models.cyber_source_capture_context_dto import CyberSourceCaptureContextDto
from pianosdk.publisher.models.datatrans_initiate_transaction_response import DatatransInitiateTransactionResponse
from pianosdk.publisher.models.datatrans_properties import DatatransProperties
from pianosdk.publisher.models.delivery_period_read_view import DeliveryPeriodReadView
from pianosdk.publisher.models.delivery_schedule_constraint_violation_dto import DeliveryScheduleConstraintViolationDTO
from pianosdk.publisher.models.delivery_schedule_constraint_violations_dto import DeliveryScheduleConstraintViolationsDTO
from pianosdk.publisher.models.delivery_schedule_read_view import DeliveryScheduleReadView
from pianosdk.publisher.models.delivery_zone import DeliveryZone
from pianosdk.publisher.models.deployment_app import DeploymentApp
from pianosdk.publisher.models.deployment_app_details import DeploymentAppDetails
from pianosdk.publisher.models.deployment_content_fields import DeploymentContentFields
from pianosdk.publisher.models.deployment_details import DeploymentDetails
from pianosdk.publisher.models.deployment_list_item import DeploymentListItem
from pianosdk.publisher.models.deployment_variant_param_dto import DeploymentVariantParamDto
from pianosdk.publisher.models.dns_forwarding_config import DnsForwardingConfig
from pianosdk.publisher.models.duration import Duration
from pianosdk.publisher.models.dynamic_subscription_access_period_info import DynamicSubscriptionAccessPeriodInfo
from pianosdk.publisher.models.dynamic_subscription_details import DynamicSubscriptionDetails
from pianosdk.publisher.models.dynamic_subscription_renewal_confirmation_dto import DynamicSubscriptionRenewalConfirmationDto
from pianosdk.publisher.models.dynamic_term_access_period import DynamicTermAccessPeriod
from pianosdk.publisher.models.early_billing_details import EarlyBillingDetails
from pianosdk.publisher.models.easypay_configuration import EasypayConfiguration
from pianosdk.publisher.models.edgil_payway_hosted_page_setup import EdgilPaywayHostedPageSetup
from pianosdk.publisher.models.eigen_create_credit_card_info_dto import EigenCreateCreditCardInfoDto
from pianosdk.publisher.models.email import Email
from pianosdk.publisher.models.erase_contract_user import EraseContractUser
from pianosdk.publisher.models.erase_conversion import EraseConversion
from pianosdk.publisher.models.erase_subscription import EraseSubscription
from pianosdk.publisher.models.erase_transaction import EraseTransaction
from pianosdk.publisher.models.erase_user import EraseUser
from pianosdk.publisher.models.erase_user_address import EraseUserAddress
from pianosdk.publisher.models.erase_user_payment import EraseUserPayment
from pianosdk.publisher.models.erase_user_payment_info import EraseUserPaymentInfo
from pianosdk.publisher.models.erase_user_response import EraseUserResponse
from pianosdk.publisher.models.erase_user_subscription_account import EraseUserSubscriptionAccount
from pianosdk.publisher.models.error_code import ErrorCode
from pianosdk.publisher.models.error_codes import ErrorCodes
from pianosdk.publisher.models.experian_configuration import ExperianConfiguration
from pianosdk.publisher.models.experience import Experience
from pianosdk.publisher.models.experience_metadata import ExperienceMetadata
from pianosdk.publisher.models.experience_stat import ExperienceStat
from pianosdk.publisher.models.experience_version import ExperienceVersion
from pianosdk.publisher.models.export import Export
from pianosdk.publisher.models.ext_provider_dto import ExtProviderDTO
from pianosdk.publisher.models.extended_experience_revision import ExtendedExperienceRevision
from pianosdk.publisher.models.external_api_configuration import ExternalAPIConfiguration
from pianosdk.publisher.models.external_api_field import ExternalAPIField
from pianosdk.publisher.models.external_api_property_schema import ExternalAPIPropertySchema
from pianosdk.publisher.models.external_api_provider_property import ExternalAPIProviderProperty
from pianosdk.publisher.models.external_css import ExternalCss
from pianosdk.publisher.models.generate_capture_context_params import GenerateCaptureContextParams
from pianosdk.publisher.models.global_template import GlobalTemplate
from pianosdk.publisher.models.global_template_deployment import GlobalTemplateDeployment
from pianosdk.publisher.models.global_template_deployment_item import GlobalTemplateDeploymentItem
from pianosdk.publisher.models.global_template_deployment_status import GlobalTemplateDeploymentStatus
from pianosdk.publisher.models.global_template_filter import GlobalTemplateFilter
from pianosdk.publisher.models.global_template_filter_item import GlobalTemplateFilterItem
from pianosdk.publisher.models.global_template_filter_sub_item import GlobalTemplateFilterSubItem
from pianosdk.publisher.models.global_template_recent_deployments import GlobalTemplateRecentDeployments
from pianosdk.publisher.models.global_template_version import GlobalTemplateVersion
from pianosdk.publisher.models.grace_period_details import GracePeriodDetails
from pianosdk.publisher.models.import_data import ImportData
from pianosdk.publisher.models.import_data_state import ImportDataState
from pianosdk.publisher.models.import_item import ImportItem
from pianosdk.publisher.models.import_profile import ImportProfile
from pianosdk.publisher.models.import_section import ImportSection
from pianosdk.publisher.models.import_user import ImportUser
from pianosdk.publisher.models.initiate_secure_fields_params import InitiateSecureFieldsParams
from pianosdk.publisher.models.input_stream import InputStream
from pianosdk.publisher.models.inquiry_comment import InquiryComment
from pianosdk.publisher.models.instrument_dto import InstrumentDTO
from pianosdk.publisher.models.key_source import KeySource
from pianosdk.publisher.models.klarna_configuration import KlarnaConfiguration
from pianosdk.publisher.models.language_model import LanguageModel
from pianosdk.publisher.models.language_stats import LanguageStats
from pianosdk.publisher.models.licensee import Licensee
from pianosdk.publisher.models.licensee_manager import LicenseeManager
from pianosdk.publisher.models.licensee_notification import LicenseeNotification
from pianosdk.publisher.models.licensee_notification_rule import LicenseeNotificationRule
from pianosdk.publisher.models.licensee_representative import LicenseeRepresentative
from pianosdk.publisher.models.light_experience import LightExperience
from pianosdk.publisher.models.light_global_template import LightGlobalTemplate
from pianosdk.publisher.models.light_offer import LightOffer
from pianosdk.publisher.models.lightweight_churn_prevention_logic import LightweightChurnPreventionLogic
from pianosdk.publisher.models.lightweight_experience import LightweightExperience
from pianosdk.publisher.models.link import Link
from pianosdk.publisher.models.link_all_status_response import LinkAllStatusResponse
from pianosdk.publisher.models.link_candidate import LinkCandidate
from pianosdk.publisher.models.linked_term_checkout_track_params import LinkedTermCheckoutTrackParams
from pianosdk.publisher.models.linked_term_churn_params import LinkedTermChurnParams
from pianosdk.publisher.models.linked_term_configuration_request import LinkedTermConfigurationRequest
from pianosdk.publisher.models.linked_term_conversion_params import LinkedTermConversionParams
from pianosdk.publisher.models.linked_term_custom_data import LinkedTermCustomData
from pianosdk.publisher.models.linked_term_custom_field_configuration_request import LinkedTermCustomFieldConfigurationRequest
from pianosdk.publisher.models.linked_term_custom_field_params import LinkedTermCustomFieldParams
from pianosdk.publisher.models.linked_term_event_request import LinkedTermEventRequest
from pianosdk.publisher.models.linked_term_payment_params import LinkedTermPaymentParams
from pianosdk.publisher.models.linked_term_purchase_params import LinkedTermPurchaseParams
from pianosdk.publisher.models.linked_term_shared_access_params import LinkedTermSharedAccessParams
from pianosdk.publisher.models.linked_term_subscription_params import LinkedTermSubscriptionParams
from pianosdk.publisher.models.linked_term_upgrade_params import LinkedTermUpgradeParams
from pianosdk.publisher.models.locale_model import LocaleModel
from pianosdk.publisher.models.mail import Mail
from pianosdk.publisher.models.mail_log import MailLog
from pianosdk.publisher.models.mail_options_verification_result import MailOptionsVerificationResult
from pianosdk.publisher.models.mandate import Mandate
from pianosdk.publisher.models.money import Money
from pianosdk.publisher.models.my_account import MyAccount
from pianosdk.publisher.models.newscycle_configuration import NewscycleConfiguration
from pianosdk.publisher.models.newscycle_configuration_test_result import NewscycleConfigurationTestResult
from pianosdk.publisher.models.notification import Notification
from pianosdk.publisher.models.obi_configuration import ObiConfiguration
from pianosdk.publisher.models.offer_list import OfferList
from pianosdk.publisher.models.offer_model import OfferModel
from pianosdk.publisher.models.offer_template import OfferTemplate
from pianosdk.publisher.models.offer_template_categories import OfferTemplateCategories
from pianosdk.publisher.models.offer_template_content_field import OfferTemplateContentField
from pianosdk.publisher.models.offer_template_histories import OfferTemplateHistories
from pianosdk.publisher.models.offer_template_history import OfferTemplateHistory
from pianosdk.publisher.models.offer_template_revision import OfferTemplateRevision
from pianosdk.publisher.models.offer_template_sub_history import OfferTemplateSubHistory
from pianosdk.publisher.models.offer_template_variant import OfferTemplateVariant
from pianosdk.publisher.models.offer_template_version import OfferTemplateVersion
from pianosdk.publisher.models.one_source_configuration import OneSourceConfiguration
from pianosdk.publisher.models.openpay_configuration import OpenpayConfiguration
from pianosdk.publisher.models.page_info import PageInfo
from pianosdk.publisher.models.pay_source_dto import PaySourceDTO
from pianosdk.publisher.models.payee_settings_entry import PayeeSettingsEntry
from pianosdk.publisher.models.payment_inquiry import PaymentInquiry
from pianosdk.publisher.models.payment_method import PaymentMethod
from pianosdk.publisher.models.payment_method_dto import PaymentMethodDTO
from pianosdk.publisher.models.payment_provider_configuration import PaymentProviderConfiguration
from pianosdk.publisher.models.paypal_express_checkout_configuration import PaypalExpressCheckoutConfiguration
from pianosdk.publisher.models.period import Period
from pianosdk.publisher.models.period_link import PeriodLink
from pianosdk.publisher.models.period_link_candidate import PeriodLinkCandidate
from pianosdk.publisher.models.period_reference_dto import PeriodReferenceDTO
from pianosdk.publisher.models.period_settings import PeriodSettings
from pianosdk.publisher.models.permission_dto import PermissionDTO
from pianosdk.publisher.models.platform_billing_configuration_dto import PlatformBillingConfigurationDTO
from pianosdk.publisher.models.pp_configuration import PpConfiguration
from pianosdk.publisher.models.ppc_currency_validation_dto import PpcCurrencyValidationDto
from pianosdk.publisher.models.ppc_web_model import PpcWebModel
from pianosdk.publisher.models.price_dto import PriceDTO
from pianosdk.publisher.models.promo_code import PromoCode
from pianosdk.publisher.models.promotion import Promotion
from pianosdk.publisher.models.promotion_applicable_term_container import PromotionApplicableTermContainer
from pianosdk.publisher.models.promotion_fixed_discount import PromotionFixedDiscount
from pianosdk.publisher.models.promotion_stats import PromotionStats
from pianosdk.publisher.models.promotion_term_stats import PromotionTermStats
from pianosdk.publisher.models.reallocation_batch import ReallocationBatch
from pianosdk.publisher.models.redemption_page import RedemptionPage
from pianosdk.publisher.models.region import Region
from pianosdk.publisher.models.region_simple_model import RegionSimpleModel
from pianosdk.publisher.models.rendered_email import RenderedEmail
from pianosdk.publisher.models.report_response import ReportResponse
from pianosdk.publisher.models.resource import Resource
from pianosdk.publisher.models.resource_compact_stats import ResourceCompactStats
from pianosdk.publisher.models.resource_dto import ResourceDto
from pianosdk.publisher.models.resource_stats import ResourceStats
from pianosdk.publisher.models.resource_tag import ResourceTag
from pianosdk.publisher.models.result import Result
from pianosdk.publisher.models.sales_tax_rate_model import SalesTaxRateModel
from pianosdk.publisher.models.schedule import Schedule
from pianosdk.publisher.models.schedule_period import SchedulePeriod
from pianosdk.publisher.models.sections_counters import SectionsCounters
from pianosdk.publisher.models.send_email_step import SendEmailStep
from pianosdk.publisher.models.shared_account import SharedAccount
from pianosdk.publisher.models.shared_account_param import SharedAccountParam
from pianosdk.publisher.models.shared_subscription import SharedSubscription
from pianosdk.publisher.models.show_option_in_channel_stats import ShowOptionInChannelStats
from pianosdk.publisher.models.show_option_in_counters import ShowOptionInCounters
from pianosdk.publisher.models.source import Source
from pianosdk.publisher.models.source_eligible_term import SourceEligibleTerm
from pianosdk.publisher.models.source_ineligible_term import SourceIneligibleTerm
from pianosdk.publisher.models.source_term_change_variant import SourceTermChangeVariant
from pianosdk.publisher.models.source_term_change_variants import SourceTermChangeVariants
from pianosdk.publisher.models.split_test_object import SplitTestObject
from pianosdk.publisher.models.stripe_properties import StripeProperties
from pianosdk.publisher.models.stripe_setup_intent_model_definition import StripeSetupIntentModelDefinition
from pianosdk.publisher.models.subscription_log_item import SubscriptionLogItem
from pianosdk.publisher.models.subscription_migration_history_dto import SubscriptionMigrationHistoryDTO
from pianosdk.publisher.models.subscription_reallocation_error import SubscriptionReallocationError
from pianosdk.publisher.models.subscription_reallocation_validation_result import SubscriptionReallocationValidationResult
from pianosdk.publisher.models.subscription_restrictions import SubscriptionRestrictions
from pianosdk.publisher.models.subscription_term_change_options import SubscriptionTermChangeOptions
from pianosdk.publisher.models.subscription_upgrade_status import SubscriptionUpgradeStatus
from pianosdk.publisher.models.target_eligible_term import TargetEligibleTerm
from pianosdk.publisher.models.target_ineligible_term import TargetIneligibleTerm
from pianosdk.publisher.models.target_term_change_variant import TargetTermChangeVariant
from pianosdk.publisher.models.target_term_change_variants import TargetTermChangeVariants
from pianosdk.publisher.models.target_upgrade_option import TargetUpgradeOption
from pianosdk.publisher.models.tax_country import TaxCountry
from pianosdk.publisher.models.tax_product_categories import TaxProductCategories
from pianosdk.publisher.models.tax_product_category import TaxProductCategory
from pianosdk.publisher.models.tax_support_dto import TaxSupportDTO
from pianosdk.publisher.models.team_member import TeamMember
from pianosdk.publisher.models.template_config import TemplateConfig
from pianosdk.publisher.models.template_counter_model import TemplateCounterModel
from pianosdk.publisher.models.template_user_model import TemplateUserModel
from pianosdk.publisher.models.template_variable import TemplateVariable
from pianosdk.publisher.models.template_version import TemplateVersion
from pianosdk.publisher.models.term import Term
from pianosdk.publisher.models.term_brief import TermBrief
from pianosdk.publisher.models.term_change_billing_options import TermChangeBillingOptions
from pianosdk.publisher.models.term_change_option import TermChangeOption
from pianosdk.publisher.models.term_change_params import TermChangeParams
from pianosdk.publisher.models.term_change_variants import TermChangeVariants
from pianosdk.publisher.models.term_conversion import TermConversion
from pianosdk.publisher.models.term_conversion_dto import TermConversionDTO
from pianosdk.publisher.models.term_conversion_data import TermConversionData
from pianosdk.publisher.models.term_conversion_subscription import TermConversionSubscription
from pianosdk.publisher.models.term_from import TermFrom
from pianosdk.publisher.models.term_info import TermInfo
from pianosdk.publisher.models.term_link import TermLink
from pianosdk.publisher.models.term_period_reallocation import TermPeriodReallocation
from pianosdk.publisher.models.term_reallocation import TermReallocation
from pianosdk.publisher.models.term_short import TermShort
from pianosdk.publisher.models.term_stats import TermStats
from pianosdk.publisher.models.term_to_eligible import TermToEligible
from pianosdk.publisher.models.term_to_ineligible import TermToIneligible
from pianosdk.publisher.models.term_to_upgrade_option import TermToUpgradeOption
from pianosdk.publisher.models.term_type_dto import TermTypeDTO
from pianosdk.publisher.models.tern_change_confirmation_dto import TernChangeConfirmationDto
from pianosdk.publisher.models.transaction_item import TransactionItem
from pianosdk.publisher.models.translation_map_revision import TranslationMapRevision
from pianosdk.publisher.models.translation_stats import TranslationStats
from pianosdk.publisher.models.update_access_period_params import UpdateAccessPeriodParams
from pianosdk.publisher.models.update_billing_configuration_request import UpdateBillingConfigurationRequest
from pianosdk.publisher.models.update_delivery_schedule_response import UpdateDeliveryScheduleResponse
from pianosdk.publisher.models.update_linked_term_request import UpdateLinkedTermRequest
from pianosdk.publisher.models.upgrade_checkout_flow import UpgradeCheckoutFlow
from pianosdk.publisher.models.upgrade_offer_model import UpgradeOfferModel
from pianosdk.publisher.models.upgrade_offer_name import UpgradeOfferName
from pianosdk.publisher.models.upgrade_offer_option_model import UpgradeOfferOptionModel
from pianosdk.publisher.models.upgrade_offer_variant import UpgradeOfferVariant
from pianosdk.publisher.models.upgrade_option import UpgradeOption
from pianosdk.publisher.models.upgrade_option_variants import UpgradeOptionVariants
from pianosdk.publisher.models.upgrade_options import UpgradeOptions
from pianosdk.publisher.models.upgrade_options_variant import UpgradeOptionsVariant
from pianosdk.publisher.models.upgrade_sources import UpgradeSources
from pianosdk.publisher.models.upgrade_subscription_step import UpgradeSubscriptionStep
from pianosdk.publisher.models.upgrade_targets import UpgradeTargets
from pianosdk.publisher.models.user import User
from pianosdk.publisher.models.user_access_dto import UserAccessDto
from pianosdk.publisher.models.user_address import UserAddress
from pianosdk.publisher.models.user_address_dto import UserAddressDto
from pianosdk.publisher.models.user_address_history import UserAddressHistory
from pianosdk.publisher.models.user_alias_dto import UserAliasDto
from pianosdk.publisher.models.user_audit import UserAudit
from pianosdk.publisher.models.user_billing_address import UserBillingAddress
from pianosdk.publisher.models.user_conversion_dto import UserConversionDTO
from pianosdk.publisher.models.user_details import UserDetails
from pianosdk.publisher.models.user_dto import UserDto
from pianosdk.publisher.models.user_info import UserInfo
from pianosdk.publisher.models.user_note import UserNote
from pianosdk.publisher.models.user_payment import UserPayment
from pianosdk.publisher.models.user_payment_dto import UserPaymentDTO
from pianosdk.publisher.models.user_payment_details_dto import UserPaymentDetailsDTO
from pianosdk.publisher.models.user_payment_info import UserPaymentInfo
from pianosdk.publisher.models.user_payment_refund_dto import UserPaymentRefundDTO
from pianosdk.publisher.models.user_provider_configuration import UserProviderConfiguration
from pianosdk.publisher.models.user_ref import UserRef
from pianosdk.publisher.models.user_subscription import UserSubscription
from pianosdk.publisher.models.user_subscription_account import UserSubscriptionAccount
from pianosdk.publisher.models.user_subscription_dto import UserSubscriptionDto
from pianosdk.publisher.models.user_subscription_list_item import UserSubscriptionListItem
from pianosdk.publisher.models.users_import_result import UsersImportResult
from pianosdk.publisher.models.variant_item import VariantItem
from pianosdk.publisher.models.version_item import VersionItem
from pianosdk.publisher.models.voucher import Voucher
from pianosdk.publisher.models.vouchering_policy import VoucheringPolicy
from pianosdk.publisher.models.webhook_config import WebhookConfig
from pianosdk.publisher.models.webhook_event import WebhookEvent
from pianosdk.publisher.models.webhook_response import WebhookResponse
from pianosdk.publisher.models.webhook_settings import WebhookSettings
from pianosdk.publisher.models.webhook_status import WebhookStatus
from pianosdk.publisher.models.zuora_configuration import ZuoraConfiguration
from pianosdk.publisher.models.zuora_connect_configuration import ZuoraConnectConfiguration




from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class ContractIpRange(BaseModel):
    ip_range: Optional[str] = None
    contract_ip_range_id: Optional[str] = None
    status: Optional[str] = None


ContractIpRange.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class PayeeSettingsEntry(BaseModel):
    merchant_account_id: Optional[str] = None
    payee_email: Optional[str] = None


PayeeSettingsEntry.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class BraintreeMerchantAccountIdEntry(BaseModel):
    currency: Optional[str] = None
    merchant_account_id: Optional[str] = None


BraintreeMerchantAccountIdEntry.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class Bill(BaseModel):
    bill_id: Optional[str] = None
    type: Optional[str] = None
    creation_date: Optional[str] = None
    status: Optional[str] = None
    url: Optional[str] = None
    rid: Optional[str] = None
    resource_name: Optional[str] = None
    resource_image_url: Optional[str] = None
    name: Optional[str] = None
    payment_billing_plan: Optional[str] = None
    cancelable: Optional[str] = None
    issued_to_email: Optional[str] = None


Bill.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class EraseTransaction(BaseModel):
    tracking_id: Optional[str] = None
    sender_email: Optional[str] = None


EraseTransaction.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.linked_term_custom_field_params import LinkedTermCustomFieldParams
from typing import List


class LinkedTermCustomFieldConfigurationRequest(BaseModel):
    custom_fields: Optional['List[LinkedTermCustomFieldParams]'] = None


LinkedTermCustomFieldConfigurationRequest.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class TermTypeDTO(BaseModel):
    type_id: Optional[str] = None
    type_name: Optional[str] = None
    type_enum_name: Optional[str] = None


TermTypeDTO.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class DatatransApplePayConfig(BaseModel):
    url: Optional[str] = None


DatatransApplePayConfig.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from typing import List


class LinkedTermSharedAccessParams(BaseModel):
    subscription_id: Optional[str] = None
    user_tokens: Optional[List[str]] = None


LinkedTermSharedAccessParams.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class DnsForwardingConfig(BaseModel):
    aid: Optional[str] = None
    config_id: Optional[str] = None
    status: Optional[str] = None
    cname_status: Optional[str] = None
    ssl_status: Optional[str] = None
    content: Optional[str] = None


DnsForwardingConfig.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class PeriodReferenceDTO(BaseModel):
    period_pub_id: Optional[str] = None
    index_in_array: Optional[int] = None


PeriodReferenceDTO.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class PerformanceMetricsDto(BaseModel):
    ga_account: Optional[str] = None
    is_enabled: Optional[str] = None
    track_only_aids: Optional[str] = None


PerformanceMetricsDto.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.anon.models.access import Access
from pianosdk.anon.models.term import Term


class TermConversion(BaseModel):
    term_conversion_id: Optional[str] = None
    term: Optional['Term'] = None
    type: Optional[str] = None
    aid: Optional[str] = None
    user_access: Optional['Access'] = None
    create_date: Optional[datetime] = None


TermConversion.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.id.models.custom_field_attribute_dto import CustomFieldAttributeDto
from pianosdk.id.models.tooltip import Tooltip
from pianosdk.id.models.validator import Validator
from typing import List


class CustomFieldDefinitionDto(BaseModel):
    field_name: Optional[str] = None
    title: Optional[str] = None
    comment: Optional[str] = None
    editable: Optional[bool] = None
    data_type: Optional[str] = None
    validators: Optional['List[Validator]'] = None
    options: Optional[List[str]] = None
    favourite_options: Optional[List[str]] = None
    options_link: Optional[int] = None
    set_name: Optional[str] = None
    required_by_default: Optional[bool] = None
    values_count: Optional[int] = None
    archived: Optional[bool] = None
    default_sort_order: Optional[int] = None
    attribute: Optional['CustomFieldAttributeDto'] = None
    tooltip: Optional['Tooltip'] = None
    parent: Optional[int] = None
    hidden: Optional[bool] = None


CustomFieldDefinitionDto.model_rebuild()



from datetime import datetime
from io import StringIO
from typing import TextIO, Dict, List, Union

from pianosdk.api_response import ApiResponse
from pianosdk.base_api import BaseApi
from pianosdk.configuration import Configuration
from pianosdk.httpwrap import HttpCallBack
from pianosdk.utils import _json_deserialize, _encode_parameter
from pianosdk.publisher.models.user_billing_address import UserBillingAddress


class PublisherUserBillingAddressApi(BaseApi):
    def __init__(self, config: Configuration, http_callback: HttpCallBack = None) -> None:
        super().__init__(config, http_callback)

    def create(self, aid: str, uid: str, country: str, region: str, postal_code: str, type: int, city: str = None, address_line1: str = None, address_line2: str = None, address_line3: str = None) -> ApiResponse[UserBillingAddress]:
        _url_path = '/api/v3/publisher/user/billingAddress/create'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'uid': _encode_parameter(uid),
            'country': _encode_parameter(country),
            'region': _encode_parameter(region),
            'city': _encode_parameter(city),
            'postal_code': _encode_parameter(postal_code),
            'address_line1': _encode_parameter(address_line1),
            'address_line2': _encode_parameter(address_line2),
            'address_line3': _encode_parameter(address_line3),
            'type': _encode_parameter(type)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, UserBillingAddress)
        return _result

    def delete(self, aid: str, uid: str, address_pub_id: str) -> ApiResponse[UserBillingAddress]:
        _url_path = '/api/v3/publisher/user/billingAddress/delete'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'uid': _encode_parameter(uid),
            'address_pub_id': _encode_parameter(address_pub_id)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, UserBillingAddress)
        return _result

    def get(self, aid: str, uid: str, address_pub_id: str) -> ApiResponse[UserBillingAddress]:
        _url_path = '/api/v3/publisher/user/billingAddress/get'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'uid': _encode_parameter(uid),
            'address_pub_id': _encode_parameter(address_pub_id)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, UserBillingAddress)
        return _result

    def get_by_payment(self, aid: str, user_payment_id: str) -> ApiResponse[UserBillingAddress]:
        _url_path = '/api/v3/publisher/user/billingAddress/getByPayment'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'user_payment_id': _encode_parameter(user_payment_id)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, UserBillingAddress)
        return _result

    def get_by_payment_info(self, aid: str, user_payment_info_id: str) -> ApiResponse[UserBillingAddress]:
        _url_path = '/api/v3/publisher/user/billingAddress/getByPaymentInfo'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'user_payment_info_id': _encode_parameter(user_payment_info_id)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, UserBillingAddress)
        return _result

    def list(self, aid: str, uid: str) -> ApiResponse[List[UserBillingAddress]]:
        _url_path = '/api/v3/publisher/user/billingAddress/list'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'uid': _encode_parameter(uid)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, UserBillingAddress)
        return _result




from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class EraseConversion(BaseModel):
    term_conversion_id: Optional[str] = None
    browser: Optional[str] = None
    experience: Optional[str] = None
    user_address: Optional[str] = None
    geo_location: Optional[str] = None
    zone: Optional[str] = None


EraseConversion.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class ReallocationBatch(BaseModel):
    subscribers_count: Optional[int] = None
    access_end_date: Optional[datetime] = None
    renewal_date: Optional[datetime] = None


ReallocationBatch.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class DeliveryPeriodReadView(BaseModel):
    is_from_editable: Optional[str] = None
    is_deletable: Optional[str] = None
    is_donation: Optional[bool] = None
    address_pub_id: Optional[str] = None
    is_address_editable: Optional[str] = None
    to: Optional[str] = None
    is_to_editable: Optional[str] = None
    delivery_period_pub_id: Optional[str] = None
    _from: Optional[str] = None


DeliveryPeriodReadView.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class TermChangeParams(BaseModel):
    billing_timing: Optional[str] = None
    immediate_access: Optional[bool] = None
    prorate_access: Optional[bool] = None


TermChangeParams.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class LinkedTermUpgradeParams(BaseModel):
    from_subscription_id: Optional[str] = None


LinkedTermUpgradeParams.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class ApplyPaymentMethodDTO(BaseModel):
    updated_subscription_count: Optional[int] = None
    update_failed_subscription_count: Optional[int] = None


ApplyPaymentMethodDTO.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class CyberSourceCaptureContextDto(BaseModel):
    tracking_id: Optional[str] = None
    capture_context: Optional[str] = None


CyberSourceCaptureContextDto.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.term import Term
from pianosdk.publisher.models.user import User


class UserConversionDTO(BaseModel):
    user: Optional['User'] = None
    term: Optional['Term'] = None


UserConversionDTO.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class CheckSubscriptionResponse(BaseModel):
    type: Optional[str] = None
    user_token: Optional[str] = None
    term_id: Optional[str] = None


CheckSubscriptionResponse.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.source_eligible_term import SourceEligibleTerm
from pianosdk.publisher.models.source_ineligible_term import SourceIneligibleTerm
from typing import List


class UpgradeSources(BaseModel):
    eligible_options: Optional['List[SourceEligibleTerm]'] = None
    ineligible_options: Optional['List[SourceIneligibleTerm]'] = None


UpgradeSources.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.tax_product_category import TaxProductCategory
from typing import List


class TaxProductCategories(BaseModel):
    term_level_categories: Optional['List[TaxProductCategory]'] = None
    categories: Optional['List[TaxProductCategory]'] = None


TaxProductCategories.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.import_user import ImportUser
from typing import List


class CheckUsersEmailResult(BaseModel):
    existing_emails: Optional['List[ImportUser]'] = None
    existing_but_not_bounded_emails: Optional['List[ImportUser]'] = None
    new_emails: Optional['List[ImportUser]'] = None
    invalid_emails: Optional['List[ImportUser]'] = None


CheckUsersEmailResult.model_rebuild()



from datetime import datetime
from io import StringIO
from typing import TextIO, Dict, List, Union

from pianosdk.api_response import ApiResponse
from pianosdk.base_api import BaseApi
from pianosdk.configuration import Configuration
from pianosdk.httpwrap import HttpCallBack
from pianosdk.utils import _json_deserialize, _encode_parameter
from pianosdk.id.models.social_additional_input_request import SocialAdditionalInputRequest


class PublisherLoginSocialApi(BaseApi):
    def __init__(self, config: Configuration, http_callback: HttpCallBack = None) -> None:
        super().__init__(config, http_callback)

    def social_code(self, aid: str, api_token: str, response_id: str) -> ApiResponse[Dict]:
        _url_path = '/id/api/v1/publisher/login/social/code'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {
            'aid': _encode_parameter(aid),
            'api_token': _encode_parameter(api_token),
            'response_id': _encode_parameter(response_id)
        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {

        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response)
        return _result

    def social_code_additional(self, aid: str, api_token: str, form_id: str = None, additional_input_state: str = None, body: SocialAdditionalInputRequest = None) -> ApiResponse[Dict]:
        _url_path = '/id/api/v1/publisher/login/social/codeAdditional'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {
            'aid': _encode_parameter(aid),
            'api_token': _encode_parameter(api_token),
            'form_id': _encode_parameter(form_id),
            'additional_input_state': _encode_parameter(additional_input_state)
        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {

        }

        _body = body and body.dict()
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response)
        return _result

    def social_code_confirm(self, aid: str, api_token: str, linking_state: str, email: str = None, password: str = None, confimed_token: str = None) -> ApiResponse[Dict]:
        _url_path = '/id/api/v1/publisher/login/social/codeConfirm'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {
            'aid': _encode_parameter(aid),
            'api_token': _encode_parameter(api_token),
            'email': _encode_parameter(email),
            'password': _encode_parameter(password),
            'confimed_token': _encode_parameter(confimed_token),
            'linking_state': _encode_parameter(linking_state)
        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {

        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response)
        return _result

